==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebStepDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebStepDescription } from "./WebStepDescription";
/**
 * @hidden
 */
export let WebStepDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStepDescriptionMetadata extends Base {
        static b(a) {
            if (WebStepDescriptionMetadata.a == null) {
                WebStepDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStepDescriptionMetadata.c(WebStepDescriptionMetadata.a);
            }
            if (a.k(WebStepDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebStepDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Step");
            a.item("__tagNameWC", "String:igc-step");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Invalid", "Boolean");
            a.item("Active", "Boolean");
            a.item("Optional", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Complete", "Boolean");
        }
        static d(a) {
            WebStepDescriptionMetadata.b(a);
            a.ad("WebStep", () => new WebStepDescription());
            a.ac("WebStep", WebStepDescriptionMetadata.a);
        }
    }
    WebStepDescriptionMetadata.$t = markType(WebStepDescriptionMetadata, 'WebStepDescriptionMetadata');
    WebStepDescriptionMetadata.a = null;
    return WebStepDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebStepDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebStepDescription } from "./WebStepDescription";
/**
 * @hidden
 */
export let WebStepDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStepDescriptionMetadata extends Base {
        static b(a) {
            if (WebStepDescriptionMetadata.a == null) {
                WebStepDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStepDescriptionMetadata.c(WebStepDescriptionMetadata.a);
            }
            if (a.k(WebStepDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebStepDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Step");
            a.item("__tagNameWC", "String:igc-step");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Invalid", "Boolean");
            a.item("Active", "Boolean");
            a.item("Optional", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Complete", "Boolean");
        }
        static d(a) {
            WebStepDescriptionMetadata.b(a);
            a.ae("WebStep", () => new WebStepDescription());
            a.ad("WebStep", WebStepDescriptionMetadata.a);
        }
    }
    WebStepDescriptionMetadata.$t = markType(WebStepDescriptionMetadata, 'WebStepDescriptionMetadata');
    WebStepDescriptionMetadata.a = null;
    return WebStepDescriptionMetadata;
})();
